@@ -1,4 +1,5 @@
 from urge.base import ProcManager, action
+from path import Path
 
 
 def web_screenshot(url: str, target: str = "./", **kwargs) -> str:
@@ -22,7 +23,8 @@ def web_screenshot(url: str, target: str = "./", **kwargs) -> str:
         page.set_viewport_size({"width": 375, "height": 635})
         page.goto(url, wait_until="networkidle")
         # page.screenshot(path=f'./example-{browser_type.name}haha.png')
-        file_name = f'{target}screenshot{datetime.now().strftime("%m-%d_%H:%M:%S")}.png'
+        target = Path(target) 
+        file_name = target/f'screenshot{datetime.now().strftime("%m-%d-%H-%M-%S")}.png'
         page.screenshot(path=file_name)
         print(f"🤖 : DONE")
         print(f'The file is at {file_name}')
