@@ -38,7 +38,7 @@ def post_builder(name, **kwd):
             _config = FREE_MAP[name]
             _query = {_config.Q: q}
             _params = P(
-                _type='json',
+                _type="json",
                 url=_config.API,
                 headers=_token,
                 params={**_query, **_config.CONFIG, **kwd},
@@ -75,13 +75,13 @@ def trans_post(q: str, **kwargs) -> t.Union[Result, dict]:
 
 def trans_filter(res: Result, full=False):
     # There will be a problem when using token
-    basic = res.result.get('basic')
+    basic = res.result.get("basic")
     d = {}
     if basic:
         # if basic exists, q must be one word,
         basic = utils.drop(basic, keys=["us-speech", "uk-speech"])
-        basic["web_dict"] = res.result.get('webdict').get('url')
-        d['simple_translation'] = res.result.get("translation")[0]
+        basic["web_dict"] = res.result.get("webdict").get("url")
+        d["simple_translation"] = res.result.get("translation")[0]
         d.update(basic)
         if not full:
             d = d.get("explains")
@@ -118,8 +118,8 @@ def pictrans_write(res: Result, target: str = "./"):
     b = res.result.get("render_image")
     name = str(uuid1()).split("-")[0]
     pic_path = f"{target}{name}.png"
-    base64_img_bytes = b.encode('utf-8')
-    with open(pic_path, 'wb') as file_to_save:
+    base64_img_bytes = b.encode("utf-8")
+    with open(pic_path, "wb") as file_to_save:
         decoded_image_data = base64.decodebytes(base64_img_bytes)
         file_to_save.write(decoded_image_data)
     return res
@@ -134,9 +134,9 @@ def pic_translate(path: str):
 
 
 def pic2base64(path: str, **kwargs):
-    with open(path, 'rb') as f:
+    with open(path, "rb") as f:
         # q = base64.b64encode(f.read())
-        return base64.b64encode(f.read()).decode('utf-8')
+        return base64.b64encode(f.read()).decode("utf-8")
         # return q.decode('utf-8')
 
 
@@ -155,10 +155,10 @@ def ocr_ret(res: Result, **kwargs) -> t.Optional[t.List]:
     text_list = []
     Result = res.result.get("Result")
     if Result:
-        items = Result.get('regions')
+        items = Result.get("regions")
         for item in items:
-            for l in item['lines']:
-                text_list.append(l['text'])
+            for l in item["lines"]:
+                text_list.append(l["text"])
 
         return text_list
 
@@ -209,8 +209,8 @@ def table_write_excel(res: Result, target: t.Text = "./"):
     name = str(uuid1()).split("-")[0]
     xlsx_path = f"{target}{name}.xlsx"
     for t in tables:
-        base64_img_bytes = t.encode('utf-8')
-        with open(xlsx_path, 'wb') as file_to_save:
+        base64_img_bytes = t.encode("utf-8")
+        with open(xlsx_path, "wb") as file_to_save:
             decoded_image_data = base64.decodebytes(base64_img_bytes)
             file_to_save.write(decoded_image_data)
     return res
